"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    application_name: str,
    deployment_group_name: str,
    service_role_arn: str,
    deployment_config_name: str = None,
    ec2_tag_filters: List = None,
    on_premises_instance_tag_filters: List = None,
    auto_scaling_groups: List = None,
    trigger_configurations: List = None,
    alarm_configuration: Dict = None,
    auto_rollback_configuration: Dict = None,
    outdated_instances_strategy: str = None,
    deployment_style: Dict = None,
    blue_green_deployment_configuration: Dict = None,
    load_balancer_info: Dict = None,
    ec2_tag_set: Dict = None,
    ecs_services: List = None,
    on_premises_tag_set: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a deployment group to which application revisions are deployed.

    Args:
        application_name(str): The name of an AWS CodeDeploy application associated with the IAM user or AWS account.
        deployment_group_name(str): The name of a new deployment group for the specified application.
        deployment_config_name(str, optional): If specified, the deployment configuration name can be either one of the predefined configurations provided with AWS CodeDeploy or a custom deployment configuration that you create by calling the create deployment configuration operation.  CodeDeployDefault.OneAtATime is the default deployment configuration. It is used if a configuration isn't specified for the deployment or deployment group. For more information about the predefined deployment configurations in AWS CodeDeploy, see Working with Deployment Configurations in CodeDeploy in the AWS CodeDeploy User Guide. Defaults to None.
        ec2_tag_filters(List, optional): The Amazon EC2 tags on which to filter. The deployment group includes EC2 instances with any of the specified tags. Cannot be used in the same call as ec2TagSet. Defaults to None.
        on_premises_instance_tag_filters(List, optional): The on-premises instance tags on which to filter. The deployment group includes on-premises instances with any of the specified tags. Cannot be used in the same call as OnPremisesTagSet. Defaults to None.
        auto_scaling_groups(List, optional): A list of associated Amazon EC2 Auto Scaling groups. Defaults to None.
        service_role_arn(str): A service role Amazon Resource Name (ARN) that allows AWS CodeDeploy to act on the user's behalf when interacting with AWS services.
        trigger_configurations(List, optional): Information about triggers to create when the deployment group is created. For examples, see Create a Trigger for an AWS CodeDeploy Event in the AWS CodeDeploy User Guide. Defaults to None.
        alarm_configuration(Dict, optional): Information to add about Amazon CloudWatch alarms when the deployment group is created. Defaults to None.
        auto_rollback_configuration(Dict, optional): Configuration information for an automatic rollback that is added when a deployment group is created. Defaults to None.
        outdated_instances_strategy(str, optional): Indicates what happens when new EC2 instances are launched mid-deployment and do not receive the deployed application revision. If this option is set to UPDATE or is unspecified, CodeDeploy initiates one or more 'auto-update outdated instances' deployments to apply the deployed application revision to the new EC2 instances. If this option is set to IGNORE, CodeDeploy does not initiate a deployment to update the new EC2 instances. This may result in instances having different revisions. Defaults to None.
        deployment_style(Dict, optional): Information about the type of deployment, in-place or blue/green, that you want to run and whether to route deployment traffic behind a load balancer. Defaults to None.
        blue_green_deployment_configuration(Dict, optional): Information about blue/green deployment options for a deployment group. Defaults to None.
        load_balancer_info(Dict, optional): Information about the load balancer used in a deployment. Defaults to None.
        ec2_tag_set(Dict, optional): Information about groups of tags applied to EC2 instances. The deployment group includes only EC2 instances identified by all the tag groups. Cannot be used in the same call as ec2TagFilters. Defaults to None.
        ecs_services(List, optional):  The target Amazon ECS services in the deployment group. This applies only to deployment groups that use the Amazon ECS compute platform. A target Amazon ECS service is specified as an Amazon ECS cluster and service name pair using the format <clustername>:<servicename>. . Defaults to None.
        on_premises_tag_set(Dict, optional): Information about groups of tags applied to on-premises instances. The deployment group includes only on-premises instances identified by all of the tag groups. Cannot be used in the same call as onPremisesInstanceTagFilters. Defaults to None.
        tags(List, optional):  The metadata that you apply to CodeDeploy deployment groups to help you organize and categorize them. Each tag consists of a key and an optional value, both of which you define. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.deployment.group.create(
                ctx, application_name=value, deployment_group_name=value, service_role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.deployment.group.create application_name=value, deployment_group_name=value, service_role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="create_deployment_group",
        op_kwargs={
            "applicationName": application_name,
            "deploymentGroupName": deployment_group_name,
            "deploymentConfigName": deployment_config_name,
            "ec2TagFilters": ec2_tag_filters,
            "onPremisesInstanceTagFilters": on_premises_instance_tag_filters,
            "autoScalingGroups": auto_scaling_groups,
            "serviceRoleArn": service_role_arn,
            "triggerConfigurations": trigger_configurations,
            "alarmConfiguration": alarm_configuration,
            "autoRollbackConfiguration": auto_rollback_configuration,
            "outdatedInstancesStrategy": outdated_instances_strategy,
            "deploymentStyle": deployment_style,
            "blueGreenDeploymentConfiguration": blue_green_deployment_configuration,
            "loadBalancerInfo": load_balancer_info,
            "ec2TagSet": ec2_tag_set,
            "ecsServices": ecs_services,
            "onPremisesTagSet": on_premises_tag_set,
            "tags": tags,
        },
    )


async def delete(hub, ctx, application_name: str, deployment_group_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a deployment group.

    Args:
        application_name(str): The name of an AWS CodeDeploy application associated with the IAM user or AWS account.
        deployment_group_name(str): The name of a deployment group for the specified application.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.deployment.group.delete(
                ctx, application_name=value, deployment_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.deployment.group.delete application_name=value, deployment_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="delete_deployment_group",
        op_kwargs={
            "applicationName": application_name,
            "deploymentGroupName": deployment_group_name,
        },
    )


async def get(hub, ctx, application_name: str, deployment_group_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a deployment group.

    Args:
        application_name(str): The name of an AWS CodeDeploy application associated with the IAM user or AWS account.
        deployment_group_name(str): The name of a deployment group for the specified application.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.deployment.group.get(
                ctx, application_name=value, deployment_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.deployment.group.get application_name=value, deployment_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="get_deployment_group",
        op_kwargs={
            "applicationName": application_name,
            "deploymentGroupName": deployment_group_name,
        },
    )


async def list_all(hub, ctx, application_name: str, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the deployment groups for an application registered with the IAM user or AWS account.

    Args:
        application_name(str): The name of an AWS CodeDeploy application associated with the IAM user or AWS account.
        next_token(str, optional): An identifier returned from the previous list deployment groups call. It can be used to return the next set of deployment groups in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.deployment.group.list_all(
                ctx, application_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.deployment.group.list_all application_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="list_deployment_groups",
        op_kwargs={"applicationName": application_name, "nextToken": next_token},
    )


async def update(
    hub,
    ctx,
    application_name: str,
    current_deployment_group_name: str,
    new_deployment_group_name: str = None,
    deployment_config_name: str = None,
    ec2_tag_filters: List = None,
    on_premises_instance_tag_filters: List = None,
    auto_scaling_groups: List = None,
    service_role_arn: str = None,
    trigger_configurations: List = None,
    alarm_configuration: Dict = None,
    auto_rollback_configuration: Dict = None,
    outdated_instances_strategy: str = None,
    deployment_style: Dict = None,
    blue_green_deployment_configuration: Dict = None,
    load_balancer_info: Dict = None,
    ec2_tag_set: Dict = None,
    ecs_services: List = None,
    on_premises_tag_set: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Changes information about a deployment group.

    Args:
        application_name(str): The application name that corresponds to the deployment group to update.
        current_deployment_group_name(str): The current name of the deployment group.
        new_deployment_group_name(str, optional): The new name of the deployment group, if you want to change it. Defaults to None.
        deployment_config_name(str, optional): The replacement deployment configuration name to use, if you want to change it. Defaults to None.
        ec2_tag_filters(List, optional): The replacement set of Amazon EC2 tags on which to filter, if you want to change them. To keep the existing tags, enter their names. To remove tags, do not enter any tag names. Defaults to None.
        on_premises_instance_tag_filters(List, optional): The replacement set of on-premises instance tags on which to filter, if you want to change them. To keep the existing tags, enter their names. To remove tags, do not enter any tag names. Defaults to None.
        auto_scaling_groups(List, optional): The replacement list of Auto Scaling groups to be included in the deployment group, if you want to change them. To keep the Auto Scaling groups, enter their names. To remove Auto Scaling groups, do not enter any Auto Scaling group names. Defaults to None.
        service_role_arn(str, optional): A replacement ARN for the service role, if you want to change it. Defaults to None.
        trigger_configurations(List, optional): Information about triggers to change when the deployment group is updated. For examples, see Edit a Trigger in a CodeDeploy Deployment Group in the AWS CodeDeploy User Guide. Defaults to None.
        alarm_configuration(Dict, optional): Information to add or change about Amazon CloudWatch alarms when the deployment group is updated. Defaults to None.
        auto_rollback_configuration(Dict, optional): Information for an automatic rollback configuration that is added or changed when a deployment group is updated. Defaults to None.
        outdated_instances_strategy(str, optional): Indicates what happens when new EC2 instances are launched mid-deployment and do not receive the deployed application revision. If this option is set to UPDATE or is unspecified, CodeDeploy initiates one or more 'auto-update outdated instances' deployments to apply the deployed application revision to the new EC2 instances. If this option is set to IGNORE, CodeDeploy does not initiate a deployment to update the new EC2 instances. This may result in instances having different revisions. Defaults to None.
        deployment_style(Dict, optional): Information about the type of deployment, either in-place or blue/green, you want to run and whether to route deployment traffic behind a load balancer. Defaults to None.
        blue_green_deployment_configuration(Dict, optional): Information about blue/green deployment options for a deployment group. Defaults to None.
        load_balancer_info(Dict, optional): Information about the load balancer used in a deployment. Defaults to None.
        ec2_tag_set(Dict, optional): Information about groups of tags applied to on-premises instances. The deployment group includes only EC2 instances identified by all the tag groups. Defaults to None.
        ecs_services(List, optional):  The target Amazon ECS services in the deployment group. This applies only to deployment groups that use the Amazon ECS compute platform. A target Amazon ECS service is specified as an Amazon ECS cluster and service name pair using the format <clustername>:<servicename>. . Defaults to None.
        on_premises_tag_set(Dict, optional): Information about an on-premises instance tag set. The deployment group includes only on-premises instances identified by all the tag groups. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.deployment.group.update(
                ctx, application_name=value, current_deployment_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.deployment.group.update application_name=value, current_deployment_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="update_deployment_group",
        op_kwargs={
            "applicationName": application_name,
            "currentDeploymentGroupName": current_deployment_group_name,
            "newDeploymentGroupName": new_deployment_group_name,
            "deploymentConfigName": deployment_config_name,
            "ec2TagFilters": ec2_tag_filters,
            "onPremisesInstanceTagFilters": on_premises_instance_tag_filters,
            "autoScalingGroups": auto_scaling_groups,
            "serviceRoleArn": service_role_arn,
            "triggerConfigurations": trigger_configurations,
            "alarmConfiguration": alarm_configuration,
            "autoRollbackConfiguration": auto_rollback_configuration,
            "outdatedInstancesStrategy": outdated_instances_strategy,
            "deploymentStyle": deployment_style,
            "blueGreenDeploymentConfiguration": blue_green_deployment_configuration,
            "loadBalancerInfo": load_balancer_info,
            "ec2TagSet": ec2_tag_set,
            "ecsServices": ecs_services,
            "onPremisesTagSet": on_premises_tag_set,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    license_configuration_arn: str,
    max_results: int = None,
    next_token: str = None,
    filters: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all license usage records for a license configuration, displaying license consumption details by resource at a selected point in time. Use this action to audit the current license consumption for any license inventory and configuration.

    Args:
        license_configuration_arn(str): Amazon Resource Name (ARN) of the license configuration.
        max_results(int, optional): Maximum number of results to return in a single call. Defaults to None.
        next_token(str, optional): Token for the next set of results. Defaults to None.
        filters(List, optional): Filters to scope the results. The following filters and logical operators are supported:    resourceArn - The ARN of the license configuration resource. Logical operators are EQUALS | NOT_EQUALS.    resourceType - The resource type (EC2_INSTANCE | EC2_HOST | EC2_AMI | SYSTEMS_MANAGER_MANAGED_INSTANCE). Logical operators are EQUALS | NOT_EQUALS.    resourceAccount - The ID of the account that owns the resource. Logical operators are EQUALS | NOT_EQUALS.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.usage_for_license_configuration.list(
                ctx, license_configuration_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.usage_for_license_configuration.list license_configuration_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="list_usage_for_license_configuration",
        op_kwargs={
            "LicenseConfigurationArn": license_configuration_arn,
            "MaxResults": max_results,
            "NextToken": next_token,
            "Filters": filters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    channel_name: str,
    channel_type: str = None,
    single_master_configuration: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a signaling channel.   CreateSignalingChannel is an asynchronous operation.

    Args:
        channel_name(str): A name for the signaling channel that you are creating. It must be unique for each AWS account and AWS Region.
        channel_type(str, optional): A type of the signaling channel that you are creating. Currently, SINGLE_MASTER is the only supported channel type. . Defaults to None.
        single_master_configuration(Dict, optional): A structure containing the configuration for the SINGLE_MASTER channel type. . Defaults to None.
        tags(List, optional): A set of tags (key-value pairs) that you want to associate with this channel. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisvideo.signaling_channel.init.create(
                ctx, channel_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisvideo.signaling_channel.init.create channel_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisvideo",
        operation="create_signaling_channel",
        op_kwargs={
            "ChannelName": channel_name,
            "ChannelType": channel_type,
            "SingleMasterConfiguration": single_master_configuration,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, channel_arn: str, current_version: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a specified signaling channel. DeleteSignalingChannel is an asynchronous operation. If you don't specify the channel's current version, the most recent version is deleted.

    Args:
        channel_arn(str): The Amazon Resource Name (ARN) of the signaling channel that you want to delete.
        current_version(str, optional): The current version of the signaling channel that you want to delete. You can obtain the current version by invoking the DescribeSignalingChannel or ListSignalingChannels API operations. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisvideo.signaling_channel.init.delete(
                ctx, channel_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisvideo.signaling_channel.init.delete channel_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisvideo",
        operation="delete_signaling_channel",
        op_kwargs={"ChannelARN": channel_arn, "CurrentVersion": current_version},
    )


async def describe(hub, ctx, channel_name: str = None, channel_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the most current information about the signaling channel. You must specify either the name or the Amazon Resource Name (ARN) of the channel that you want to describe.

    Args:
        channel_name(str, optional): The name of the signaling channel that you want to describe. Defaults to None.
        channel_arn(str, optional): The ARN of the signaling channel that you want to describe. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisvideo.signaling_channel.init.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisvideo.signaling_channel.init.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisvideo",
        operation="describe_signaling_channel",
        op_kwargs={"ChannelName": channel_name, "ChannelARN": channel_arn},
    )


async def list_all(
    hub,
    ctx,
    max_results: int = None,
    next_token: str = None,
    channel_name_condition: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns an array of ChannelInfo objects. Each object describes a signaling channel. To retrieve only those channels that satisfy a specific condition, you can specify a ChannelNameCondition.

    Args:
        max_results(int, optional): The maximum number of channels to return in the response. The default is 500. Defaults to None.
        next_token(str, optional): If you specify this parameter, when the result of a ListSignalingChannels operation is truncated, the call returns the NextToken in the response. To get another batch of channels, provide this token in your next request. Defaults to None.
        channel_name_condition(Dict, optional): Optional: Returns only the channels that satisfy a specific condition. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisvideo.signaling_channel.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisvideo.signaling_channel.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisvideo",
        operation="list_signaling_channels",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "ChannelNameCondition": channel_name_condition,
        },
    )


async def update(
    hub,
    ctx,
    channel_arn: str,
    current_version: str,
    single_master_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the existing signaling channel. This is an asynchronous operation and takes time to complete.  If the MessageTtlSeconds value is updated (either increased or reduced), it only applies to new messages sent via this channel after it's been updated. Existing messages are still expired as per the previous MessageTtlSeconds value.

    Args:
        channel_arn(str): The Amazon Resource Name (ARN) of the signaling channel that you want to update.
        current_version(str): The current version of the signaling channel that you want to update.
        single_master_configuration(Dict, optional): The structure containing the configuration for the SINGLE_MASTER type of the signaling channel that you want to update. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisvideo.signaling_channel.init.update(
                ctx, channel_arn=value, current_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisvideo.signaling_channel.init.update channel_arn=value, current_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisvideo",
        operation="update_signaling_channel",
        op_kwargs={
            "ChannelARN": channel_arn,
            "CurrentVersion": current_version,
            "SingleMasterConfiguration": single_master_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def get(hub, ctx, user_pool_id: str, client_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets the UI Customization information for a particular app client's app UI, if there is something set. If nothing is set for the particular client, but there is an existing pool level customization (app clientId will be ALL), then that is returned. If nothing is present, then an empty shape is returned.

    Args:
        user_pool_id(str): The user pool ID for the user pool.
        client_id(str, optional): The client ID for the client app. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.ui_customization.get(ctx, user_pool_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.ui_customization.get user_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="get_ui_customization",
        op_kwargs={"UserPoolId": user_pool_id, "ClientId": client_id},
    )


async def set_(
    hub,
    ctx,
    user_pool_id: str,
    client_id: str = None,
    css: str = None,
    image_file: bytes = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Sets the UI customization information for a user pool's built-in app UI. You can specify app UI customization settings for a single client (with a specific clientId) or for all clients (by setting the clientId to ALL). If you specify ALL, the default configuration will be used for every client that has no UI customization set previously. If you specify UI customization settings for a particular client, it will no longer fall back to the ALL configuration.   To use this API, your user pool must have a domain associated with it. Otherwise, there is no place to host the app's pages, and the service will throw an error.

    Args:
        user_pool_id(str): The user pool ID for the user pool.
        client_id(str, optional): The client ID for the client app. Defaults to None.
        css(str, optional): The CSS values in the UI customization. Defaults to None.
        image_file(bytes, optional): The uploaded logo image for the UI customization. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.ui_customization.set(ctx, user_pool_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.ui_customization.set user_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="set_ui_customization",
        op_kwargs={
            "UserPoolId": user_pool_id,
            "ClientId": client_id,
            "CSS": css,
            "ImageFile": image_file,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete_multiple(hub, ctx, backup_vault_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes event notifications for the specified backup vault.

    Args:
        backup_vault_name(str): The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Region where they are created. They consist of lowercase letters, numbers, and hyphens.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.backup.vault.notification.delete_multiple(
                ctx, backup_vault_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.backup.vault.notification.delete_multiple backup_vault_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="delete_backup_vault_notifications",
        op_kwargs={"BackupVaultName": backup_vault_name},
    )


async def get_all(hub, ctx, backup_vault_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns event notifications for the specified backup vault.

    Args:
        backup_vault_name(str): The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the AWS Region where they are created. They consist of lowercase letters, numbers, and hyphens.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.backup.vault.notification.get_all(
                ctx, backup_vault_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.backup.vault.notification.get_all backup_vault_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="get_backup_vault_notifications",
        op_kwargs={"BackupVaultName": backup_vault_name},
    )


async def put_multiple(
    hub, ctx, backup_vault_name: str, sns_topic_arn: str, backup_vault_events: List
) -> None:
    r"""
    **Autogenerated function**

    Turns on notifications on a backup vault for the specified topic and events.

    Args:
        backup_vault_name(str): The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the AWS Region where they are created. They consist of lowercase letters, numbers, and hyphens.
        sns_topic_arn(str): The Amazon Resource Name (ARN) that specifies the topic for a backup vault’s events; for example, arn:aws:sns:us-west-2:111122223333:MyVaultTopic.
        backup_vault_events(List): An array of events that indicate the status of jobs to back up resources to the backup vault.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.backup.vault.notification.put_multiple(
                ctx, backup_vault_name=value, sns_topic_arn=value, backup_vault_events=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.backup.vault.notification.put_multiple backup_vault_name=value, sns_topic_arn=value, backup_vault_events=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="put_backup_vault_notifications",
        op_kwargs={
            "BackupVaultName": backup_vault_name,
            "SNSTopicArn": sns_topic_arn,
            "BackupVaultEvents": backup_vault_events,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub, ctx, approval_rule_template_name: str, approval_rule_template_description: str
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the description for a specified approval rule template.

    Args:
        approval_rule_template_name(str): The name of the template for which you want to update the description.
        approval_rule_template_description(str): The updated description of the approval rule template.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.approval_rule_template.description.update(
                ctx, approval_rule_template_name=value, approval_rule_template_description=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.approval_rule_template.description.update approval_rule_template_name=value, approval_rule_template_description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="update_approval_rule_template_description",
        op_kwargs={
            "approvalRuleTemplateName": approval_rule_template_name,
            "approvalRuleTemplateDescription": approval_rule_template_description,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def approve(hub, ctx, skill_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Associates a skill with the organization under the customer's AWS account. If a skill is private, the user implicitly accepts access to this skill during enablement.

    Args:
        skill_id(str): The unique identifier of the skill.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.skill.init.approve(ctx, skill_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.skill.init.approve skill_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="approve_skill",
        op_kwargs={"SkillId": skill_id},
    )


async def list_all(
    hub,
    ctx,
    skill_group_arn: str = None,
    enablement_type: str = None,
    skill_type: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all enabled skills in a specific skill group.

    Args:
        skill_group_arn(str, optional): The ARN of the skill group for which to list enabled skills. Defaults to None.
        enablement_type(str, optional): Whether the skill is enabled under the user's account. Defaults to None.
        skill_type(str, optional): Whether the skill is publicly available or is a private skill. Defaults to None.
        next_token(str, optional): An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults. Defaults to None.
        max_results(int, optional): The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.skill.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.skill.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="list_skills",
        op_kwargs={
            "SkillGroupArn": skill_group_arn,
            "EnablementType": enablement_type,
            "SkillType": skill_type,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def reject(hub, ctx, skill_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates a skill from the organization under a user's AWS account. If the skill is a private skill, it moves to an AcceptStatus of PENDING. Any private or public skill that is rejected can be added later by calling the ApproveSkill API.

    Args:
        skill_id(str): The unique identifier of the skill.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.skill.init.reject(ctx, skill_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.skill.init.reject skill_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="reject_skill",
        op_kwargs={"SkillId": skill_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def check(hub, ctx, domain_name: str, idn_lang_code: str = None) -> Dict:
    r"""
    **Autogenerated function**

    This operation checks the availability of one domain name. Note that if the availability status of a domain is pending, you must submit another request to determine the availability of the domain name.

    Args:
        domain_name(str): The name of the domain that you want to get availability for. The top-level domain (TLD), such as .com, must be a TLD that Route 53 supports. For a list of supported TLDs, see Domains that You Can Register with Amazon Route 53 in the Amazon Route 53 Developer Guide. The domain name can contain only the following characters:   Letters a through z. Domain names are not case sensitive.   Numbers 0 through 9.   Hyphen (-). You can't specify a hyphen at the beginning or end of a label.    Period (.) to separate the labels in the name, such as the . in example.com.   Internationalized domain names are not supported for some top-level domains. To determine whether the TLD that you want to use supports internationalized domain names, see Domains that You Can Register with Amazon Route 53. For more information, see Formatting Internationalized Domain Names. .
        idn_lang_code(str, optional): Reserved for future use. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.domain.availability.check(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.domain.availability.check domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="check_domain_availability",
        op_kwargs={"DomainName": domain_name, "IdnLangCode": idn_lang_code},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    launch_template_name: str,
    launch_template_data: Dict,
    dry_run: bool = None,
    client_token: str = None,
    version_description: str = None,
    tag_specifications: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a launch template. A launch template contains the parameters to launch an instance. When you launch an instance using RunInstances, you can specify a launch template instead of providing the launch parameters in the request. For more information, see Launching an instance from a launch templatein the Amazon Elastic Compute Cloud User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        client_token(str, optional): Unique, case-sensitive identifier you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency. Constraint: Maximum 128 ASCII characters. Defaults to None.
        launch_template_name(str): A name for the launch template.
        version_description(str, optional): A description for the first version of the launch template. Defaults to None.
        launch_template_data(Dict): The information for the launch template.
        tag_specifications(List, optional): The tags to apply to the launch template during creation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.launch_template.init.create(
                ctx, launch_template_name=value, launch_template_data=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.launch_template.init.create launch_template_name=value, launch_template_data=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_launch_template",
        op_kwargs={
            "DryRun": dry_run,
            "ClientToken": client_token,
            "LaunchTemplateName": launch_template_name,
            "VersionDescription": version_description,
            "LaunchTemplateData": launch_template_data,
            "TagSpecifications": tag_specifications,
        },
    )


async def delete(
    hub,
    ctx,
    dry_run: bool = None,
    launch_template_id: str = None,
    launch_template_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a launch template. Deleting a launch template deletes all of its versions.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        launch_template_id(str, optional): The ID of the launch template. You must specify either the launch template ID or launch template name in the request. Defaults to None.
        launch_template_name(str, optional): The name of the launch template. You must specify either the launch template ID or launch template name in the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.launch_template.init.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.launch_template.init.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_launch_template",
        op_kwargs={
            "DryRun": dry_run,
            "LaunchTemplateId": launch_template_id,
            "LaunchTemplateName": launch_template_name,
        },
    )


async def describe_all(
    hub,
    ctx,
    dry_run: bool = None,
    launch_template_ids: List = None,
    launch_template_names: List = None,
    filters: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more launch templates.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        launch_template_ids(List, optional): One or more launch template IDs. Defaults to None.
        launch_template_names(List, optional): One or more launch template names. Defaults to None.
        filters(List, optional): One or more filters.    create-time - The time the launch template was created.    launch-template-name - The name of the launch template.    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  . Defaults to None.
        next_token(str, optional): The token to request the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value. This value can be between 1 and 200. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.launch_template.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.launch_template.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_launch_templates",
        op_kwargs={
            "DryRun": dry_run,
            "LaunchTemplateIds": launch_template_ids,
            "LaunchTemplateNames": launch_template_names,
            "Filters": filters,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def modify(
    hub,
    ctx,
    dry_run: bool = None,
    client_token: str = None,
    launch_template_id: str = None,
    launch_template_name: str = None,
    default_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies a launch template. You can specify which version of the launch template to set as the default version. When launching an instance, the default version applies when a launch template version is not specified.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        client_token(str, optional): Unique, case-sensitive identifier you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency. Constraint: Maximum 128 ASCII characters. Defaults to None.
        launch_template_id(str, optional): The ID of the launch template. You must specify either the launch template ID or launch template name in the request. Defaults to None.
        launch_template_name(str, optional): The name of the launch template. You must specify either the launch template ID or launch template name in the request. Defaults to None.
        default_version(str, optional): The version number of the launch template to set as the default version. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.launch_template.init.modify(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.launch_template.init.modify
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_launch_template",
        op_kwargs={
            "DryRun": dry_run,
            "ClientToken": client_token,
            "LaunchTemplateId": launch_template_id,
            "LaunchTemplateName": launch_template_name,
            "DefaultVersion": default_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, organization_id: str, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an access control rule for the specified WorkMail organization.

    Args:
        organization_id(str): The identifier for the organization.
        name(str): The name of the access control rule.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.access_control.rule.delete(
                ctx, organization_id=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.access_control.rule.delete organization_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="delete_access_control_rule",
        op_kwargs={"OrganizationId": organization_id, "Name": name},
    )


async def list_all(hub, ctx, organization_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Lists the access control rules for the specified organization.

    Args:
        organization_id(str): The identifier for the organization.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.access_control.rule.list_all(
                ctx, organization_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.access_control.rule.list_all organization_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="list_access_control_rules",
        op_kwargs={"OrganizationId": organization_id},
    )


async def put(
    hub,
    ctx,
    name: str,
    effect: str,
    description: str,
    organization_id: str,
    ip_ranges: List = None,
    not_ip_ranges: List = None,
    actions: List = None,
    not_actions: List = None,
    user_ids: List = None,
    not_user_ids: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds a new access control rule for the specified organization. The rule allows or denies access to the organization for the specified IPv4 addresses, access protocol actions, and user IDs. Adding a new rule with the same name as an existing rule replaces the older rule.

    Args:
        name(str): The rule name.
        effect(str): The rule effect.
        description(str): The rule description.
        ip_ranges(List, optional): IPv4 CIDR ranges to include in the rule. Defaults to None.
        not_ip_ranges(List, optional): IPv4 CIDR ranges to exclude from the rule. Defaults to None.
        actions(List, optional): Access protocol actions to include in the rule. Valid values include ActiveSync, AutoDiscover, EWS, IMAP, SMTP, WindowsOutlook, and WebMail. Defaults to None.
        not_actions(List, optional): Access protocol actions to exclude from the rule. Valid values include ActiveSync, AutoDiscover, EWS, IMAP, SMTP, WindowsOutlook, and WebMail. Defaults to None.
        user_ids(List, optional): User IDs to include in the rule. Defaults to None.
        not_user_ids(List, optional): User IDs to exclude from the rule. Defaults to None.
        organization_id(str): The identifier of the organization.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.access_control.rule.put(
                ctx, name=value, effect=value, description=value, organization_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.access_control.rule.put name=value, effect=value, description=value, organization_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="put_access_control_rule",
        op_kwargs={
            "Name": name,
            "Effect": effect,
            "Description": description,
            "IpRanges": ip_ranges,
            "NotIpRanges": not_ip_ranges,
            "Actions": actions,
            "NotActions": not_actions,
            "UserIds": user_ids,
            "NotUserIds": not_user_ids,
            "OrganizationId": organization_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def attach(hub, ctx, policy_name: str, principal: str) -> None:
    r"""
    **Autogenerated function**

    Attaches the specified policy to the specified principal (certificate or other credential).  Note: This API is deprecated. Please use AttachPolicy instead.

    Args:
        policy_name(str): The policy name.
        principal(str): The principal, which can be a certificate ARN (as returned from the CreateCertificate operation) or an Amazon Cognito ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.principal.policy.attach(
                ctx, policy_name=value, principal=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.principal.policy.attach policy_name=value, principal=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="attach_principal_policy",
        op_kwargs={"policyName": policy_name, "principal": principal},
    )


async def detach(hub, ctx, policy_name: str, principal: str) -> None:
    r"""
    **Autogenerated function**

    Removes the specified policy from the specified certificate.  Note: This API is deprecated. Please use DetachPolicy instead.

    Args:
        policy_name(str): The name of the policy to detach.
        principal(str): The principal. Valid principals are CertificateArn (arn:aws:iot:region:accountId:cert/certificateId), thingGroupArn (arn:aws:iot:region:accountId:thinggroup/groupName) and CognitoId (region:id).
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.principal.policy.detach(
                ctx, policy_name=value, principal=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.principal.policy.detach policy_name=value, principal=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="detach_principal_policy",
        op_kwargs={"policyName": policy_name, "principal": principal},
    )


async def list_all(
    hub,
    ctx,
    principal: str,
    marker: str = None,
    page_size: int = None,
    ascending_order: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the policies attached to the specified principal. If you use an Cognito identity, the ID must be in AmazonCognito Identity format.  Note: This API is deprecated. Please use ListAttachedPolicies instead.

    Args:
        principal(str): The principal. Valid principals are CertificateArn (arn:aws:iot:region:accountId:cert/certificateId), thingGroupArn (arn:aws:iot:region:accountId:thinggroup/groupName) and CognitoId (region:id).
        marker(str, optional): The marker for the next set of results. Defaults to None.
        page_size(int, optional): The result page size. Defaults to None.
        ascending_order(bool, optional): Specifies the order for results. If true, results are returned in ascending creation order. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.principal.policy.list_all(ctx, principal=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.principal.policy.list_all principal=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_principal_policies",
        op_kwargs={
            "principal": principal,
            "marker": marker,
            "pageSize": page_size,
            "ascendingOrder": ascending_order,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, instance_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Provides summary information about the security profiles for the specified Amazon Connect instance. For more information about security profiles, see Security Profiles in the Amazon Connect Administrator Guide.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        next_token(str, optional): The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.security.profile.list_all(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.security.profile.list_all instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="list_security_profiles",
        op_kwargs={
            "InstanceId": instance_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "certificate_revocation_list"


__func_alias__ = {"import_": "import"}


async def export(hub, ctx, client_vpn_endpoint_id: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Downloads the client certificate revocation list for the specified Client VPN endpoint.

    Args:
        client_vpn_endpoint_id(str): The ID of the Client VPN endpoint.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.client_vpn.client.certificate_revocation_list_.export(ctx, client_vpn_endpoint_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.client_vpn.client.certificate_revocation_list.export client_vpn_endpoint_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="export_client_vpn_client_certificate_revocation_list",
        op_kwargs={"ClientVpnEndpointId": client_vpn_endpoint_id, "DryRun": dry_run},
    )


async def import_(
    hub,
    ctx,
    client_vpn_endpoint_id: str,
    certificate_revocation_list: str,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Uploads a client certificate revocation list to the specified Client VPN endpoint. Uploading a client certificate revocation list overwrites the existing client certificate revocation list. Uploading a client certificate revocation list resets existing client connections.

    Args:
        client_vpn_endpoint_id(str): The ID of the Client VPN endpoint to which the client certificate revocation list applies.
        certificate_revocation_list(str): The client certificate revocation list file. For more information, see Generate a Client Certificate Revocation List in the AWS Client VPN Administrator Guide.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.client_vpn.client.certificate_revocation_list_.import(ctx, client_vpn_endpoint_id=value, certificate_revocation_list=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.client_vpn.client.certificate_revocation_list.import client_vpn_endpoint_id=value, certificate_revocation_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="import_client_vpn_client_certificate_revocation_list",
        op_kwargs={
            "ClientVpnEndpointId": client_vpn_endpoint_id,
            "CertificateRevocationList": certificate_revocation_list,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, key_id: str, grant_tokens: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the public key of an asymmetric CMK. Unlike the private key of a asymmetric CMK, which never leaves AWS KMS unencrypted, callers with kms:GetPublicKey permission can download the public key of an asymmetric CMK. You can share the public key to allow others to encrypt messages and verify signatures outside of AWS KMS. For information about symmetric and asymmetric CMKs, see Using Symmetric and Asymmetric CMKs in the AWS Key Management Service Developer Guide. You do not need to download the public key. Instead, you can use the public key within AWS KMS by calling the Encrypt, ReEncrypt, or Verify operations with the identifier of an asymmetric CMK. When you use the public key within AWS KMS, you benefit from the authentication, authorization, and logging that are part of every AWS KMS operation. You also reduce of risk of encrypting data that cannot be decrypted. These features are not effective outside of AWS KMS. For details, see Special Considerations for Downloading Public Keys. To help you use the public key safely outside of AWS KMS, GetPublicKey returns important information about the public key in the response, including:    CustomerMasterKeySpec: The type of key material in the public key, such as RSA_4096 or ECC_NIST_P521.    KeyUsage: Whether the key is used for encryption or signing.    EncryptionAlgorithms or SigningAlgorithms: A list of the encryption algorithms or the signing algorithms for the key.   Although AWS KMS cannot enforce these restrictions on external operations, it is crucial that you use this information to prevent the public key from being used improperly. For example, you can prevent a public signing key from being used encrypt data, or prevent a public key from being used with an encryption algorithm that is not supported by AWS KMS. You can also avoid errors, such as using the wrong signing algorithm in a verification operation. The CMK that you use for this operation must be in a compatible key state. For details, see Key state: Effect on your CMK in the AWS Key Management Service Developer Guide.  Cross-account use: Yes. To perform this operation with a CMK in a different AWS account, specify the key ARN or alias ARN in the value of the KeyId parameter.  Required permissions: kms:GetPublicKey (key policy)  Related operations: CreateKey

    Args:
        key_id(str): Identifies the asymmetric CMK that includes the public key. To specify a CMK, use its key ID, key ARN, alias name, or alias ARN. When using an alias name, prefix it with "alias/". To specify a CMK in a different AWS account, you must use the key ARN or alias ARN. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    Alias name: alias/ExampleAlias    Alias ARN: arn:aws:kms:us-east-2:111122223333:alias/ExampleAlias    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey. To get the alias name and alias ARN, use ListAliases.
        grant_tokens(List, optional): A list of grant tokens. Use a grant token when your permission to call this operation comes from a new grant that has not yet achieved eventual consistency. For more information, see Grant token in the AWS Key Management Service Developer Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.public_key.get(ctx, key_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.public_key.get key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="get_public_key",
        op_kwargs={"KeyId": key_id, "GrantTokens": grant_tokens},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, type_: str, delegation_set_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the maximum number of hosted zones that you can associate with the specified reusable delegation set. For the default limit, see Limits in the Amazon Route 53 Developer Guide. To request a higher limit, open a case.

    Args:
        type_(str): Specify MAX_ZONES_BY_REUSABLE_DELEGATION_SET to get the maximum number of hosted zones that you can associate with the specified reusable delegation set.
        delegation_set_id(str): The ID of the delegation set that you want to get the limit for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.reusable_delegation_set_.limit.get(
                ctx, type_=value, delegation_set_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.reusable_delegation_set_.limit.get type_=value, delegation_set_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="get_reusable_delegation_set_limit",
        op_kwargs={"Type": type_, "DelegationSetId": delegation_set_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub,
    ctx,
    service_code: str,
    attribute_name: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of attribute values. Attibutes are similar to the details in a Price List API offer file. For a list of available attributes, see Offer File Definitions in the Amazon Web Services Billing and Cost Management User Guide.

    Args:
        service_code(str): The service code for the service whose attributes you want to retrieve. For example, if you want the retrieve an EC2 attribute, use AmazonEC2.
        attribute_name(str): The name of the attribute that you want to retrieve the values for, such as volumeType.
        next_token(str, optional): The pagination token that indicates the next set of results that you want to retrieve. Defaults to None.
        max_results(int, optional): The maximum number of results to return in response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pricing.attribute_value.get_all(
                ctx, service_code=value, attribute_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pricing.attribute_value.get_all service_code=value, attribute_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pricing",
        operation="get_attribute_values",
        op_kwargs={
            "ServiceCode": service_code,
            "AttributeName": attribute_name,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, template_name: str, template_body: str, set_as_default: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new version of a fleet provisioning template.

    Args:
        template_name(str): The name of the fleet provisioning template.
        template_body(str): The JSON formatted contents of the fleet provisioning template.
        set_as_default(bool, optional): Sets a fleet provision template version as the default version. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.provisioning.template.version.create(
                ctx, template_name=value, template_body=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.provisioning.template.version.create template_name=value, template_body=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="create_provisioning_template_version",
        op_kwargs={
            "templateName": template_name,
            "templateBody": template_body,
            "setAsDefault": set_as_default,
        },
    )


async def delete(hub, ctx, template_name: str, version_id: int) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a fleet provisioning template version.

    Args:
        template_name(str): The name of the fleet provisioning template version to delete.
        version_id(int): The fleet provisioning template version ID to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.provisioning.template.version.delete(
                ctx, template_name=value, version_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.provisioning.template.version.delete template_name=value, version_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_provisioning_template_version",
        op_kwargs={"templateName": template_name, "versionId": version_id},
    )


async def describe(hub, ctx, template_name: str, version_id: int) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a fleet provisioning template version.

    Args:
        template_name(str): The template name.
        version_id(int): The fleet provisioning template version ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.provisioning.template.version.describe(
                ctx, template_name=value, version_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.provisioning.template.version.describe template_name=value, version_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_provisioning_template_version",
        op_kwargs={"templateName": template_name, "versionId": version_id},
    )


async def list_all(
    hub, ctx, template_name: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    A list of fleet provisioning template versions.

    Args:
        template_name(str): The name of the fleet provisioning template.
        max_results(int, optional): The maximum number of results to return at one time. Defaults to None.
        next_token(str, optional): A token to retrieve the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.provisioning.template.version.list_all(
                ctx, template_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.provisioning.template.version.list_all template_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_provisioning_template_versions",
        op_kwargs={
            "templateName": template_name,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, bucket: str, expected_bucket_owner: str = None) -> Dict:
    r"""
    **Autogenerated function**

     Bucket lifecycle configuration now supports specifying a lifecycle rule using an object key name prefix, one or more object tags, or a combination of both. Accordingly, this section describes the latest API. The response describes the new filter element that you can use to specify a filter to select a subset of objects to which the rule applies. If you are using a previous version of the lifecycle configuration, it still works. For the earlier action, see GetBucketLifecycle.  Returns the lifecycle configuration information set on the bucket. For information about lifecycle configuration, see Object Lifecycle Management. To use this operation, you must have permission to perform the s3:GetLifecycleConfiguration action. The bucket owner has this permission, by default. The bucket owner can grant this permission to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources.  GetBucketLifecycleConfiguration has the following special error:   Error code: NoSuchLifecycleConfiguration    Description: The lifecycle configuration does not exist.   HTTP Status Code: 404 Not Found   SOAP Fault Code Prefix: Client     The following operations are related to GetBucketLifecycleConfiguration:    GetBucketLifecycle     PutBucketLifecycle     DeleteBucketLifecycle

    Args:
        bucket(str): The name of the bucket for which to get the lifecycle information.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.lifecycle.configuration.get(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.lifecycle.configuration.get bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_bucket_lifecycle_configuration",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def put(
    hub,
    ctx,
    bucket: str,
    lifecycle_configuration: Dict = None,
    expected_bucket_owner: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Creates a new lifecycle configuration for the bucket or replaces an existing lifecycle configuration. For information about lifecycle configuration, see Managing your storage lifecycle.  Bucket lifecycle configuration now supports specifying a lifecycle rule using an object key name prefix, one or more object tags, or a combination of both. Accordingly, this section describes the latest API. The previous version of the API supported filtering based only on an object key name prefix, which is supported for backward compatibility. For the related API description, see PutBucketLifecycle.   Rules  You specify the lifecycle configuration in your request body. The lifecycle configuration is specified as XML consisting of one or more rules. Each rule consists of the following:   Filter identifying a subset of objects to which the rule applies. The filter can be based on a key name prefix, object tags, or a combination of both.   Status whether the rule is in effect.   One or more lifecycle transition and expiration actions that you want Amazon S3 to perform on the objects identified by the filter. If the state of your bucket is versioning-enabled or versioning-suspended, you can have many versions of the same object (one current version and zero or more noncurrent versions). Amazon S3 provides predefined actions that you can specify for current and noncurrent object versions.   For more information, see Object Lifecycle Management and Lifecycle Configuration Elements.  Permissions  By default, all Amazon S3 resources are private, including buckets, objects, and related subresources (for example, lifecycle configuration and website configuration). Only the resource owner (that is, the AWS account that created it) can access the resource. The resource owner can optionally grant access permissions to others by writing an access policy. For this operation, a user must get the s3:PutLifecycleConfiguration permission. You can also explicitly deny permissions. Explicit deny also supersedes any other permissions. If you want to block users or accounts from removing or deleting objects from your bucket, you must deny them permissions for the following actions:   s3:DeleteObject   s3:DeleteObjectVersion   s3:PutLifecycleConfiguration   For more information about permissions, see Managing Access Permissions to Your Amazon S3 Resources. The following are related to PutBucketLifecycleConfiguration:    Examples of Lifecycle Configuration     GetBucketLifecycleConfiguration     DeleteBucketLifecycle

    Args:
        bucket(str): The name of the bucket for which to set the configuration.
        lifecycle_configuration(Dict, optional): Container for lifecycle rules. You can add as many as 1,000 rules. Defaults to None.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.lifecycle.configuration.put(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.lifecycle.configuration.put bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="put_bucket_lifecycle_configuration",
        op_kwargs={
            "Bucket": bucket,
            "LifecycleConfiguration": lifecycle_configuration,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, policy_name: str, policy_document: str, set_as_default: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new version of the specified AWS IoT policy. To update a policy, create a new policy version. A managed policy can have up to five versions. If the policy has five versions, you must use DeletePolicyVersion to delete an existing version before you create a new one. Optionally, you can set the new version as the policy's default version. The default version is the operative version (that is, the version that is in effect for the certificates to which the policy is attached).

    Args:
        policy_name(str): The policy name.
        policy_document(str): The JSON document that describes the policy. Minimum length of 1. Maximum length of 2048, excluding whitespace.
        set_as_default(bool, optional): Specifies whether the policy version is set as the default. When this parameter is true, the new policy version becomes the operative version (that is, the version that is in effect for the certificates to which the policy is attached). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.policy.version.create(
                ctx, policy_name=value, policy_document=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.policy.version.create policy_name=value, policy_document=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="create_policy_version",
        op_kwargs={
            "policyName": policy_name,
            "policyDocument": policy_document,
            "setAsDefault": set_as_default,
        },
    )


async def delete(hub, ctx, policy_name: str, policy_version_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified version of the specified policy. You cannot delete the default version of a policy using this API. To delete the default version of a policy, use DeletePolicy. To find out which version of a policy is marked as the default version, use ListPolicyVersions.

    Args:
        policy_name(str): The name of the policy.
        policy_version_id(str): The policy version ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.policy.version.delete(
                ctx, policy_name=value, policy_version_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.policy.version.delete policy_name=value, policy_version_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_policy_version",
        op_kwargs={"policyName": policy_name, "policyVersionId": policy_version_id},
    )


async def get(hub, ctx, policy_name: str, policy_version_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the specified policy version.

    Args:
        policy_name(str): The name of the policy.
        policy_version_id(str): The policy version ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.policy.version.get(
                ctx, policy_name=value, policy_version_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.policy.version.get policy_name=value, policy_version_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="get_policy_version",
        op_kwargs={"policyName": policy_name, "policyVersionId": policy_version_id},
    )


async def list_all(hub, ctx, policy_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Lists the versions of the specified policy and identifies the default version.

    Args:
        policy_name(str): The policy name.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.policy.version.list_all(ctx, policy_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.policy.version.list_all policy_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_policy_versions",
        op_kwargs={"policyName": policy_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def start(hub, ctx, replication_job_id: str, description: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Starts an on-demand replication run for the specified replication job. This replication run starts immediately. This replication run is in addition to the ones already scheduled. There is a limit on the number of on-demand replications runs that you can request in a 24-hour period.

    Args:
        replication_job_id(str): The ID of the replication job.
        description(str, optional): The description of the replication run. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.on_demand.replication_run.start(
                ctx, replication_job_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.on_demand.replication_run.start replication_job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sms",
        operation="start_on_demand_replication_run",
        op_kwargs={"replicationJobId": replication_job_id, "description": description},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub,
    ctx,
    cluster_name: str,
    nodegroup_name: str,
    version: str = None,
    release_version: str = None,
    launch_template: Dict = None,
    force: bool = None,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the Kubernetes version or AMI version of an Amazon EKS managed node group. You can update a node group using a launch template only if the node group was originally deployed with a launch template. If you need to update a custom AMI in a node group that was deployed with a launch template, then update your custom AMI, specify the new ID in a new version of the launch template, and then update the node group to the new version of the launch template. If you update without a launch template, then you can update to the latest available AMI version of a node group's current Kubernetes version by not specifying a Kubernetes version in the request. You can update to the latest AMI version of your cluster's current Kubernetes version by specifying your cluster's Kubernetes version in the request. For more information, see Amazon EKS optimized Amazon Linux 2 AMI versions in the Amazon EKS User Guide. You cannot roll back a node group to an earlier Kubernetes version or AMI version. When a node in a managed node group is terminated due to a scaling action or update, the pods in that node are drained first. Amazon EKS attempts to drain the nodes gracefully and will fail if it is unable to do so. You can force the update if Amazon EKS is unable to drain the nodes as a result of a pod disruption budget issue.

    Args:
        cluster_name(str): The name of the Amazon EKS cluster that is associated with the managed node group to update.
        nodegroup_name(str): The name of the managed node group to update.
        version(str, optional): The Kubernetes version to update to. If no version is specified, then the Kubernetes version of the node group does not change. You can specify the Kubernetes version of the cluster to update the node group to the latest AMI version of the cluster's Kubernetes version. If you specify launchTemplate, and your launch template uses a custom AMI, then don't specify version, or the node group update will fail. For more information about using launch templates with Amazon EKS, see Launch template support in the Amazon EKS User Guide. Defaults to None.
        release_version(str, optional): The AMI version of the Amazon EKS optimized AMI to use for the update. By default, the latest available AMI version for the node group's Kubernetes version is used. For more information, see Amazon EKS optimized Amazon Linux 2 AMI versions  in the Amazon EKS User Guide. If you specify launchTemplate, and your launch template uses a custom AMI, then don't specify releaseVersion, or the node group update will fail. For more information about using launch templates with Amazon EKS, see Launch template support in the Amazon EKS User Guide. Defaults to None.
        launch_template(Dict, optional): An object representing a node group's launch template specification. You can only update a node group using a launch template if the node group was originally deployed with a launch template. Defaults to None.
        force(bool, optional): Force the update if the existing node group's pods are unable to be drained due to a pod disruption budget issue. If an update fails because pods could not be drained, you can force the update after it fails to terminate the old node whether or not any pods are running on the node. Defaults to None.
        client_request_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.nodegroup.version.update(
                ctx, cluster_name=value, nodegroup_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.nodegroup.version.update cluster_name=value, nodegroup_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="update_nodegroup_version",
        op_kwargs={
            "clusterName": cluster_name,
            "nodegroupName": nodegroup_name,
            "version": version,
            "releaseVersion": release_version,
            "launchTemplate": launch_template,
            "force": force,
            "clientRequestToken": client_request_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(hub, ctx, member_account_id: str) -> None:
    r"""
    **Autogenerated function**

    Associates a specified AWS account with Amazon Macie Classic as a member account.

    Args:
        member_account_id(str): The ID of the AWS account that you want to associate with Amazon Macie Classic as a member account.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie.member_account.associate(ctx, member_account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie.member_account.associate member_account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie",
        operation="associate_member_account",
        op_kwargs={"memberAccountId": member_account_id},
    )


async def disassociate(hub, ctx, member_account_id: str) -> None:
    r"""
    **Autogenerated function**

    Removes the specified member account from Amazon Macie Classic.

    Args:
        member_account_id(str): The ID of the member account that you want to remove from Amazon Macie Classic.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie.member_account.disassociate(ctx, member_account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie.member_account.disassociate member_account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie",
        operation="disassociate_member_account",
        op_kwargs={"memberAccountId": member_account_id},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all Amazon Macie Classic member accounts for the current Macie Classic administrator account.

    Args:
        next_token(str, optional): Use this parameter when paginating results. Set the value of this parameter to null on your first call to the ListMemberAccounts action. Subsequent calls to the action fill nextToken in the request with the value of nextToken from the previous response to continue listing data. . Defaults to None.
        max_results(int, optional): Use this parameter to indicate the maximum number of items that you want in the response. The default value is 250. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie.member_account.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie.member_account.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie",
        operation="list_member_accounts",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, user_name: str, marker: str = None, max_items: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the tags that are attached to the specified IAM user. The returned list of tags is sorted by tag key. For more information about tagging, see Tagging IAM resources in the IAM User Guide.

    Args:
        user_name(str): The name of the IAM user whose tags you want to see. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        marker(str, optional): Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start. Defaults to None.
        max_items(int, optional): Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true. If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.user.tag.list_all(ctx, user_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.user.tag.list_all user_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="list_user_tags",
        op_kwargs={"UserName": user_name, "Marker": marker, "MaxItems": max_items},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(hub, ctx, group_id: str, role_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Associates a role with a group. Your Greengrass core will use the role to access AWS cloud services. The role's permissions should allow Greengrass core Lambda functions to perform actions against the cloud.

    Args:
        group_id(str): The ID of the Greengrass group.
        role_arn(str): The ARN of the role you wish to associate with this group. The existence of the role is not validated.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.role.to_group.associate(
                ctx, group_id=value, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.role.to_group.associate group_id=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="associate_role_to_group",
        op_kwargs={"GroupId": group_id, "RoleArn": role_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, hosted_zone_id: str, cloud_watch_logs_log_group_arn: str
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a configuration for DNS query logging. After you create a query logging configuration, Amazon Route 53 begins to publish log data to an Amazon CloudWatch Logs log group. DNS query logs contain information about the queries that Route 53 receives for a specified public hosted zone, such as the following:   Route 53 edge location that responded to the DNS query   Domain or subdomain that was requested   DNS record type, such as A or AAAA   DNS response code, such as NoError or ServFail     Log Group and Resource Policy  Before you create a query logging configuration, perform the following operations.  If you create a query logging configuration using the Route 53 console, Route 53 performs these operations automatically.    Create a CloudWatch Logs log group, and make note of the ARN, which you specify when you create a query logging configuration. Note the following:   You must create the log group in the us-east-1 region.   You must use the same account to create the log group and the hosted zone that you want to configure query logging for.   When you create log groups for query logging, we recommend that you use a consistent prefix, for example:  /aws/route53/hosted zone name   In the next step, you'll create a resource policy, which controls access to one or more log groups and the associated Amazon Web Services resources, such as Route 53 hosted zones. There's a limit on the number of resource policies that you can create, so we recommend that you use a consistent prefix so you can use the same resource policy for all the log groups that you create for query logging.     Create a CloudWatch Logs resource policy, and give it the permissions that Route 53 needs to create log streams and to send query logs to log streams. For the value of Resource, specify the ARN for the log group that you created in the previous step. To use the same resource policy for all the CloudWatch Logs log groups that you created for query logging configurations, replace the hosted zone name with *, for example:  arn:aws:logs:us-east-1:123412341234:log-group:/aws/route53/*   You can't use the CloudWatch console to create or edit a resource policy. You must use the CloudWatch API, one of the Amazon Web Services SDKs, or the CLI.     Log Streams and Edge Locations  When Route 53 finishes creating the configuration for DNS query logging, it does the following:   Creates a log stream for an edge location the first time that the edge location responds to DNS queries for the specified hosted zone. That log stream is used to log all queries that Route 53 responds to for that edge location.   Begins to send query logs to the applicable log stream.   The name of each log stream is in the following format:   hosted zone ID/edge location code   The edge location code is a three-letter code and an arbitrarily assigned number, for example, DFW3. The three-letter code typically corresponds with the International Air Transport Association airport code for an airport near the edge location. (These abbreviations might change in the future.) For a list of edge locations, see "The Route 53 Global Network" on the Route 53 Product Details page.  Queries That Are Logged  Query logs contain only the queries that DNS resolvers forward to Route 53. If a DNS resolver has already cached the response to a query (such as the IP address for a load balancer for example.com), the resolver will continue to return the cached response. It doesn't forward another query to Route 53 until the TTL for the corresponding resource record set expires. Depending on how many DNS queries are submitted for a resource record set, and depending on the TTL for that resource record set, query logs might contain information about only one query out of every several thousand queries that are submitted to DNS. For more information about how DNS works, see Routing Internet Traffic to Your Website or Web Application in the Amazon Route 53 Developer Guide.  Log File Format  For a list of the values in each query log and the format of each value, see Logging DNS Queries in the Amazon Route 53 Developer Guide.  Pricing  For information about charges for query logs, see Amazon CloudWatch Pricing.  How to Stop Logging  If you want Route 53 to stop sending query logs to CloudWatch Logs, delete the query logging configuration. For more information, see DeleteQueryLoggingConfig.

    Args:
        hosted_zone_id(str): The ID of the hosted zone that you want to log queries for. You can log queries only for public hosted zones.
        cloud_watch_logs_log_group_arn(str): The Amazon Resource Name (ARN) for the log group that you want to Amazon Route 53 to send query logs to. This is the format of the ARN: arn:aws:logs:region:account-id:log-group:log_group_name  To get the ARN for a log group, you can use the CloudWatch console, the DescribeLogGroups API action, the describe-log-groups command, or the applicable command in one of the Amazon Web Services SDKs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.query_logging_config.create(
                ctx, hosted_zone_id=value, cloud_watch_logs_log_group_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.query_logging_config.create hosted_zone_id=value, cloud_watch_logs_log_group_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="create_query_logging_config",
        op_kwargs={
            "HostedZoneId": hosted_zone_id,
            "CloudWatchLogsLogGroupArn": cloud_watch_logs_log_group_arn,
        },
    )


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a configuration for DNS query logging. If you delete a configuration, Amazon Route 53 stops sending query logs to CloudWatch Logs. Route 53 doesn't delete any logs that are already in CloudWatch Logs. For more information about DNS query logs, see CreateQueryLoggingConfig.

    Args:
        id_(str): The ID of the configuration that you want to delete. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.query_logging_config.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.query_logging_config.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="delete_query_logging_config",
        op_kwargs={"Id": id_},
    )


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a specified configuration for DNS query logging. For more information about DNS query logs, see CreateQueryLoggingConfig and Logging DNS Queries.

    Args:
        id_(str): The ID of the configuration for DNS query logging that you want to get information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.query_logging_config.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.query_logging_config.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="get_query_logging_config",
        op_kwargs={"Id": id_},
    )


async def list_all(
    hub,
    ctx,
    hosted_zone_id: str = None,
    next_token: str = None,
    max_results: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the configurations for DNS query logging that are associated with the current account or the configuration that is associated with a specified hosted zone. For more information about DNS query logs, see CreateQueryLoggingConfig. Additional information, including the format of DNS query logs, appears in Logging DNS Queries in the Amazon Route 53 Developer Guide.

    Args:
        hosted_zone_id(str, optional): (Optional) If you want to list the query logging configuration that is associated with a hosted zone, specify the ID in HostedZoneId.  If you don't specify a hosted zone ID, ListQueryLoggingConfigs returns all of the configurations that are associated with the current account. Defaults to None.
        next_token(str, optional): (Optional) If the current account has more than MaxResults query logging configurations, use NextToken to get the second and subsequent pages of results. For the first ListQueryLoggingConfigs request, omit this value. For the second and subsequent requests, get the value of NextToken from the previous response and specify that value for NextToken in the request. Defaults to None.
        max_results(str, optional): (Optional) The maximum number of query logging configurations that you want Amazon Route 53 to return in response to the current request. If the current account has more than MaxResults configurations, use the value of NextToken in the response to get the next page of results. If you don't specify a value for MaxResults, Route 53 returns up to 100 configurations. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.query_logging_config.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.query_logging_config.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="list_query_logging_configs",
        op_kwargs={
            "HostedZoneId": hosted_zone_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, resource_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Lists all tags currently on a named resource.  A tag is a key-value pair where the key and value are case-sensitive. You can use tags to categorize and track all your ElastiCache resources, with the exception of global replication group. When you add or remove tags on replication groups, those actions will be replicated to all nodes in the replication group. For more information, see Resource-level permissions. If the cluster is not in the available state, ListTagsForResource returns an error.

    Args:
        resource_name(str): The Amazon Resource Name (ARN) of the resource for which you want the list of tags, for example arn:aws:elasticache:us-west-2:0123456789:cluster:myCluster or arn:aws:elasticache:us-west-2:0123456789:snapshot:mySnapshot. For more information about ARNs, see Amazon Resource Names (ARNs) and AWS Service Namespaces.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.tags.for_resource.list(ctx, resource_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.tags.for_resource.list resource_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="list_tags_for_resource",
        op_kwargs={"ResourceName": resource_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__sub_alias__ = ["slot_type_", "slot_type"]


async def delete(hub, ctx, name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes all versions of the slot type, including the $LATEST version. To delete a specific version of the slot type, use the DeleteSlotTypeVersion operation.  You can delete a version of a slot type only if it is not referenced. To delete a slot type that is referred to in one or more intents, you must remove those references first.    If you get the ResourceInUseException exception, the exception provides an example reference that shows the intent where the slot type is referenced. To remove the reference to the slot type, either update the intent or delete it. If you get the same exception when you attempt to delete the slot type again, repeat until the slot type has no references and the DeleteSlotType call is successful.   This operation requires permission for the lex:DeleteSlotType action.

    Args:
        name(str): The name of the slot type. The name is case sensitive. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.slot_type_.init.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.slot_type_.init.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="delete_slot_type",
        op_kwargs={"name": name},
    )


async def get(hub, ctx, name: str, version: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a specific version of a slot type. In addition to specifying the slot type name, you must specify the slot type version. This operation requires permissions for the lex:GetSlotType action.

    Args:
        name(str): The name of the slot type. The name is case sensitive. .
        version(str): The version of the slot type. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.slot_type_.init.get(ctx, name=value, version=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.slot_type_.init.get name=value, version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="get_slot_type",
        op_kwargs={"name": name, "version": version},
    )


async def get_all(
    hub, ctx, next_token: str = None, max_results: int = None, name_contains: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns slot type information as follows:    If you specify the nameContains field, returns the $LATEST version of all slot types that contain the specified string.    If you don't specify the nameContains field, returns information about the $LATEST version of all slot types.     The operation requires permission for the lex:GetSlotTypes action.

    Args:
        next_token(str, optional): A pagination token that fetches the next page of slot types. If the response to this API call is truncated, Amazon Lex returns a pagination token in the response. To fetch next page of slot types, specify the pagination token in the next request. Defaults to None.
        max_results(int, optional): The maximum number of slot types to return in the response. The default is 10. Defaults to None.
        name_contains(str, optional): Substring to match in slot type names. A slot type will be returned if any part of its name matches the substring. For example, "xyz" matches both "xyzabc" and "abcxyz.". Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.slot_type_.init.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.slot_type_.init.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="get_slot_types",
        op_kwargs={
            "nextToken": next_token,
            "maxResults": max_results,
            "nameContains": name_contains,
        },
    )


async def put(
    hub,
    ctx,
    name: str,
    description: str = None,
    enumeration_values: List = None,
    checksum: str = None,
    value_selection_strategy: str = None,
    create_version: bool = None,
    parent_slot_type_signature: str = None,
    slot_type_configurations: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a custom slot type or replaces an existing custom slot type. To create a custom slot type, specify a name for the slot type and a set of enumeration values, which are the values that a slot of this type can assume. For more information, see how-it-works. If you specify the name of an existing slot type, the fields in the request replace the existing values in the $LATEST version of the slot type. Amazon Lex removes the fields that you don't provide in the request. If you don't specify required fields, Amazon Lex throws an exception. When you update the $LATEST version of a slot type, if a bot uses the $LATEST version of an intent that contains the slot type, the bot's status field is set to NOT_BUILT. This operation requires permissions for the lex:PutSlotType action.

    Args:
        name(str): The name of the slot type. The name is not case sensitive.  The name can't match a built-in slot type name, or a built-in slot type name with "AMAZON." removed. For example, because there is a built-in slot type called AMAZON.DATE, you can't create a custom slot type called DATE. For a list of built-in slot types, see Slot Type Reference in the Alexa Skills Kit.
        description(str, optional): A description of the slot type. Defaults to None.
        enumeration_values(List, optional): A list of EnumerationValue objects that defines the values that the slot type can take. Each value can have a list of synonyms, which are additional values that help train the machine learning model about the values that it resolves for a slot.  A regular expression slot type doesn't require enumeration values. All other slot types require a list of enumeration values. When Amazon Lex resolves a slot value, it generates a resolution list that contains up to five possible values for the slot. If you are using a Lambda function, this resolution list is passed to the function. If you are not using a Lambda function you can choose to return the value that the user entered or the first value in the resolution list as the slot value. The valueSelectionStrategy field indicates the option to use. . Defaults to None.
        checksum(str, optional): Identifies a specific revision of the $LATEST version. When you create a new slot type, leave the checksum field blank. If you specify a checksum you get a BadRequestException exception. When you want to update a slot type, set the checksum field to the checksum of the most recent revision of the $LATEST version. If you don't specify the  checksum field, or if the checksum does not match the $LATEST version, you get a PreconditionFailedException exception. Defaults to None.
        value_selection_strategy(str, optional): Determines the slot resolution strategy that Amazon Lex uses to return slot type values. The field can be set to one of the following values:    ORIGINAL_VALUE - Returns the value entered by the user, if the user value is similar to the slot value.    TOP_RESOLUTION - If there is a resolution list for the slot, return the first value in the resolution list as the slot type value. If there is no resolution list, null is returned.   If you don't specify the valueSelectionStrategy, the default is ORIGINAL_VALUE. Defaults to None.
        create_version(bool, optional): When set to true a new numbered version of the slot type is created. This is the same as calling the CreateSlotTypeVersion operation. If you do not specify createVersion, the default is false. Defaults to None.
        parent_slot_type_signature(str, optional): The built-in slot type used as the parent of the slot type. When you define a parent slot type, the new slot type has all of the same configuration as the parent. Only AMAZON.AlphaNumeric is supported. Defaults to None.
        slot_type_configurations(List, optional): Configuration information that extends the parent built-in slot type. The configuration is added to the settings for the parent slot type. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.slot_type_.init.put(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.slot_type_.init.put name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="put_slot_type",
        op_kwargs={
            "name": name,
            "description": description,
            "enumerationValues": enumeration_values,
            "checksum": checksum,
            "valueSelectionStrategy": value_selection_strategy,
            "createVersion": create_version,
            "parentSlotTypeSignature": parent_slot_type_signature,
            "slotTypeConfigurations": slot_type_configurations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    role_name: str,
    assume_role_policy_document: str,
    path: str = None,
    description: str = None,
    max_session_duration: int = None,
    permissions_boundary: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new role for your account. For more information about roles, see IAM roles. For information about quotas for role names and the number of roles you can create, see IAM and STS quotas in the IAM User Guide.

    Args:
        path(str, optional):  The path to the role. For more information about paths, see IAM Identifiers in the IAM User Guide. This parameter is optional. If it is not included, it defaults to a slash (/). This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters. Defaults to None.
        role_name(str): The name of the role to create. IAM user, group, role, and policy names must be unique within the account. Names are not distinguished by case. For example, you cannot create resources named both "MyResource" and "myresource".
        assume_role_policy_document(str): The trust relationship policy document that grants an entity permission to assume the role. In IAM, you must provide a JSON policy that has been converted to a string. However, for CloudFormation templates formatted in YAML, you can provide the policy in JSON or YAML format. CloudFormation always converts a YAML policy to JSON format before submitting it to IAM. The regex pattern used to validate this parameter is a string of characters consisting of the following:   Any printable ASCII character ranging from the space character (\u0020) through the end of the ASCII character range   The printable characters in the Basic Latin and Latin-1 Supplement character set (through \u00FF)   The special characters tab (\u0009), line feed (\u000A), and carriage return (\u000D)    Upon success, the response includes the same trust policy in JSON format.
        description(str, optional): A description of the role. Defaults to None.
        max_session_duration(int, optional): The maximum session duration (in seconds) that you want to set for the specified role. If you do not specify a value for this setting, the default maximum of one hour is applied. This setting can have a value from 1 hour to 12 hours. Anyone who assumes the role from the or API can use the DurationSeconds API parameter or the duration-seconds CLI parameter to request a longer session. The MaxSessionDuration setting determines the maximum duration that can be requested using the DurationSeconds parameter. If users don't specify a value for the DurationSeconds parameter, their security credentials are valid for one hour by default. This applies when you use the AssumeRole* API operations or the assume-role* CLI operations but does not apply when you use those operations to create a console URL. For more information, see Using IAM roles in the IAM User Guide. Defaults to None.
        permissions_boundary(str, optional): The ARN of the policy that is used to set the permissions boundary for the role. Defaults to None.
        tags(List, optional): A list of tags that you want to attach to the new role. Each tag consists of a key name and an associated value. For more information about tagging, see Tagging IAM resources in the IAM User Guide.  If any one of the tags is invalid or if you exceed the allowed maximum number of tags, then the entire request fails and the resource is not created. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.role.init.create(
                ctx, role_name=value, assume_role_policy_document=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.role.init.create role_name=value, assume_role_policy_document=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="create_role",
        op_kwargs={
            "Path": path,
            "RoleName": role_name,
            "AssumeRolePolicyDocument": assume_role_policy_document,
            "Description": description,
            "MaxSessionDuration": max_session_duration,
            "PermissionsBoundary": permissions_boundary,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, role_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified role. The role must not have any policies attached. For more information about roles, see Working with roles.  Make sure that you do not have any Amazon EC2 instances running with the role you are about to delete. Deleting a role or instance profile that is associated with a running instance will break any applications running on the instance.

    Args:
        role_name(str): The name of the role to delete. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.role.init.delete(ctx, role_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.role.init.delete role_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="delete_role",
        op_kwargs={"RoleName": role_name},
    )


async def get(hub, ctx, role_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the specified role, including the role's path, GUID, ARN, and the role's trust policy that grants permission to assume the role. For more information about roles, see Working with roles.  Policies returned by this operation are URL-encoded compliant with RFC 3986. You can use a URL decoding method to convert the policy back to plain JSON text. For example, if you use Java, you can use the decode method of the java.net.URLDecoder utility class in the Java SDK. Other languages and SDKs provide similar functionality.

    Args:
        role_name(str): The name of the IAM role to get information about. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.role.init.get(ctx, role_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.role.init.get role_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="iam", operation="get_role", op_kwargs={"RoleName": role_name}
    )


async def list_all(
    hub, ctx, path_prefix: str = None, marker: str = None, max_items: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the IAM roles that have the specified path prefix. If there are none, the operation returns an empty list. For more information about roles, see Working with roles.  IAM resource-listing operations return a subset of the available attributes for the resource. For example, this operation does not return tags, even though they are an attribute of the returned object. To view all of the information for a role, see GetRole.  You can paginate the results using the MaxItems and Marker parameters.

    Args:
        path_prefix(str, optional):  The path prefix for filtering the results. For example, the prefix /application_abc/component_xyz/ gets all roles whose path starts with /application_abc/component_xyz/. This parameter is optional. If it is not included, it defaults to a slash (/), listing all roles. This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters. Defaults to None.
        marker(str, optional): Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start. Defaults to None.
        max_items(int, optional): Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true. If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.role.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.role.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="list_roles",
        op_kwargs={"PathPrefix": path_prefix, "Marker": marker, "MaxItems": max_items},
    )


async def tag(hub, ctx, role_name: str, tags: List) -> None:
    r"""
    **Autogenerated function**

    Adds one or more tags to an IAM role. The role can be a regular role or a service-linked role. If a tag with the same key name already exists, then that tag is overwritten with the new value. A tag consists of a key name and an associated value. By assigning tags to your resources, you can do the following:    Administrative grouping and discovery - Attach tags to resources to aid in organization and search. For example, you could search for all resources with the key name Project and the value MyImportantProject. Or search for all resources with the key name Cost Center and the value 41200.     Access control - Include tags in IAM user-based and resource-based policies. You can use tags to restrict access to only an IAM role that has a specified tag attached. You can also restrict access to only those resources that have a certain tag attached. For examples of policies that show how to use tags to control access, see Control access using IAM tags in the IAM User Guide.    Cost allocation - Use tags to help track which individuals and teams are using which Amazon Web Services resources.      If any one of the tags is invalid or if you exceed the allowed maximum number of tags, then the entire request fails and the resource is not created. For more information about tagging, see Tagging IAM resources in the IAM User Guide.   Amazon Web Services always interprets the tag Value as a single string. If you need to store an array, you can store comma-separated values in the string. However, you must interpret the value in your code.    For more information about tagging, see Tagging IAM identities in the IAM User Guide.

    Args:
        role_name(str): The name of the IAM role to which you want to add tags. This parameter accepts (through its regex pattern) a string of characters that consist of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        tags(List): The list of tags that you want to attach to the IAM role. Each tag consists of a key name and an associated value.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.role.init.tag(ctx, role_name=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.role.init.tag role_name=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="tag_role",
        op_kwargs={"RoleName": role_name, "Tags": tags},
    )


async def untag(hub, ctx, role_name: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Removes the specified tags from the role. For more information about tagging, see Tagging IAM resources in the IAM User Guide.

    Args:
        role_name(str): The name of the IAM role from which you want to remove tags. This parameter accepts (through its regex pattern) a string of characters that consist of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        tag_keys(List): A list of key names as a simple array of strings. The tags with matching keys are removed from the specified role.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.role.init.untag(ctx, role_name=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.role.init.untag role_name=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="untag_role",
        op_kwargs={"RoleName": role_name, "TagKeys": tag_keys},
    )


async def update(
    hub, ctx, role_name: str, description: str = None, max_session_duration: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the description or maximum session duration setting of a role.

    Args:
        role_name(str): The name of the role that you want to modify.
        description(str, optional): The new description that you want to apply to the specified role. Defaults to None.
        max_session_duration(int, optional): The maximum session duration (in seconds) that you want to set for the specified role. If you do not specify a value for this setting, the default maximum of one hour is applied. This setting can have a value from 1 hour to 12 hours. Anyone who assumes the role from the CLI or API can use the DurationSeconds API parameter or the duration-seconds CLI parameter to request a longer session. The MaxSessionDuration setting determines the maximum duration that can be requested using the DurationSeconds parameter. If users don't specify a value for the DurationSeconds parameter, their security credentials are valid for one hour by default. This applies when you use the AssumeRole* API operations or the assume-role* CLI operations but does not apply when you use those operations to create a console URL. For more information, see Using IAM roles in the IAM User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.role.init.update(ctx, role_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.role.init.update role_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="update_role",
        op_kwargs={
            "RoleName": role_name,
            "Description": description,
            "MaxSessionDuration": max_session_duration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(
    hub, ctx, network_insights_analysis_id: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified network insights analysis.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        network_insights_analysis_id(str): The ID of the network insights analysis.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.network.insight.analysis.delete(
                ctx, network_insights_analysis_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.network.insight.analysis.delete network_insights_analysis_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_network_insights_analysis",
        op_kwargs={
            "DryRun": dry_run,
            "NetworkInsightsAnalysisId": network_insights_analysis_id,
        },
    )


async def start(
    hub,
    ctx,
    network_insights_path_id: str,
    client_token: str,
    filter_in_arns: List = None,
    dry_run: bool = None,
    tag_specifications: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts analyzing the specified path. If the path is reachable, the operation returns the shortest feasible path.

    Args:
        network_insights_path_id(str): The ID of the path.
        filter_in_arns(List, optional): The Amazon Resource Names (ARN) of the resources that the path must traverse. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        tag_specifications(List, optional): The tags to apply. Defaults to None.
        client_token(str): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.network.insight.analysis.start(
                ctx, network_insights_path_id=value, client_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.network.insight.analysis.start network_insights_path_id=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="start_network_insights_analysis",
        op_kwargs={
            "NetworkInsightsPathId": network_insights_path_id,
            "FilterInArns": filter_in_arns,
            "DryRun": dry_run,
            "TagSpecifications": tag_specifications,
            "ClientToken": client_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def remove(
    hub, ctx, account_id: str, vault_name: str, tag_keys: List = None
) -> None:
    r"""
    **Autogenerated function**

    This operation removes one or more tags from the set of tags attached to a vault. For more information about tags, see Tagging Amazon S3 Glacier Resources. This operation is idempotent. The operation will be successful, even if there are no tags attached to the vault.

    Args:
        account_id(str): The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon S3 Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID.
        vault_name(str): The name of the vault.
        tag_keys(List, optional): A list of tag keys. Each corresponding tag is removed from the vault. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.tags.from_vault.remove(
                ctx, account_id=value, vault_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.tags.from_vault.remove account_id=value, vault_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="remove_tags_from_vault",
        op_kwargs={
            "accountId": account_id,
            "vaultName": vault_name,
            "TagKeys": tag_keys,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(
    hub,
    ctx,
    voice_connector_id: str,
    e164_phone_numbers: List,
    force_associate: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associates phone numbers with the specified Amazon Chime Voice Connector.

    Args:
        voice_connector_id(str): The Amazon Chime Voice Connector ID.
        e164_phone_numbers(List): List of phone numbers, in E.164 format.
        force_associate(bool, optional): If true, associates the provided phone numbers with the provided Amazon Chime Voice Connector and removes any previously existing associations. If false, does not associate any phone numbers that have previously existing associations. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.phone_number.with_.voice_connector.init.associate(
                ctx, voice_connector_id=value, e164_phone_numbers=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.phone_number.with_.voice_connector.init.associate voice_connector_id=value, e164_phone_numbers=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="associate_phone_numbers_with_voice_connector",
        op_kwargs={
            "VoiceConnectorId": voice_connector_id,
            "E164PhoneNumbers": e164_phone_numbers,
            "ForceAssociate": force_associate,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def calculate(
    hub,
    ctx,
    calculator_name: str,
    departure_position: List,
    destination_position: List,
    car_mode_options: Dict = None,
    depart_now: bool = None,
    departure_time: str = None,
    distance_unit: str = None,
    include_leg_geometry: bool = None,
    travel_mode: str = None,
    truck_mode_options: Dict = None,
    waypoint_positions: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Calculates a route given the following required parameters: DeparturePostiton and DestinationPosition. Requires that you first create a route calculator resource  By default, a request that doesn't specify a departure time uses the best time of day to travel with the best traffic conditions when calculating the route. Additional options include:    Specifying a departure time using either DepartureTime or DepartureNow. This calculates a route based on predictive traffic data at the given time.   You can't specify both DepartureTime and DepartureNow in a single request. Specifying both parameters returns an error message.     Specifying a travel mode using TravelMode. This lets you specify an additional route preference such as CarModeOptions if traveling by Car, or TruckModeOptions if traveling by Truck.

    Args:
        calculator_name(str): The name of the route calculator resource that you want to use to calculate a route. .
        car_mode_options(Dict, optional): Specifies route preferences when traveling by Car, such as avoiding routes that use ferries or tolls. Requirements: TravelMode must be specified as Car. Defaults to None.
        depart_now(bool, optional): Sets the time of departure as the current time. Uses the current time to calculate a route. Otherwise, the best time of day to travel with the best traffic conditions is used to calculate the route. Default Value: false  Valid Values: false | true . Defaults to None.
        departure_position(List): The start position for the route. Defined in WGS 84 format: [longitude, latitude].   For example, [-123.115, 49.285]     If you specify a departure that's not located on a road, Amazon Location moves the position to the nearest road.  Valid Values: [-180 to 180,-90 to 90] .
        departure_time(str, optional): Specifies the desired time of departure. Uses the given time to calculate a route. Otherwise, the best time of day to travel with the best traffic conditions is used to calculate the route.  Setting a departure time in the past returns a 400 ValidationException error.    In ISO 8601 format: YYYY-MM-DDThh:mm:ss.sssZ. For example, 2020–07-2T12:15:20.000Z+01:00   . Defaults to None.
        destination_position(List): The finish position for the route. Defined in WGS 84 format: [longitude, latitude].    For example, [-122.339, 47.615]     If you specify a destination that's not located on a road, Amazon Location moves the position to the nearest road.   Valid Values: [-180 to 180,-90 to 90] .
        distance_unit(str, optional): Set the unit system to specify the distance. Default Value: Kilometers . Defaults to None.
        include_leg_geometry(bool, optional): Set to include the geometry details in the result for each path between a pair of positions. Default Value: false  Valid Values: false | true . Defaults to None.
        travel_mode(str, optional): Specifies the mode of transport when calculating a route. Used in estimating the speed of travel and road compatibility. The TravelMode you specify determines how you specify route preferences:    If traveling by Car use the CarModeOptions parameter.   If traveling by Truck use the TruckModeOptions parameter.   Default Value: Car . Defaults to None.
        truck_mode_options(Dict, optional): Specifies route preferences when traveling by Truck, such as avoiding routes that use ferries or tolls, and truck specifications to consider when choosing an optimal road. Requirements: TravelMode must be specified as Truck. Defaults to None.
        waypoint_positions(List, optional): Specifies an ordered list of up to 23 intermediate positions to include along a route between the departure position and destination position.    For example, from the DeparturePosition [-123.115, 49.285], the route follows the order that the waypoint positions are given [[-122.757, 49.0021],[-122.349, 47.620]]     If you specify a waypoint position that's not located on a road, Amazon Location moves the position to the nearest road.  Specifying more than 23 waypoints returns a 400 ValidationException error.  Valid Values: [-180 to 180,-90 to 90] . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.route.init.calculate(
                ctx, calculator_name=value, departure_position=value, destination_position=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.route.init.calculate calculator_name=value, departure_position=value, destination_position=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="calculate_route",
        op_kwargs={
            "CalculatorName": calculator_name,
            "CarModeOptions": car_mode_options,
            "DepartNow": depart_now,
            "DeparturePosition": departure_position,
            "DepartureTime": departure_time,
            "DestinationPosition": destination_position,
            "DistanceUnit": distance_unit,
            "IncludeLegGeometry": include_leg_geometry,
            "TravelMode": travel_mode,
            "TruckModeOptions": truck_mode_options,
            "WaypointPositions": waypoint_positions,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub, ctx, ec2_instance_type: str = None, location: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    The GameLift service limits and current utilization for an AWS Region or location. Instance limits control the number of instances, per instance type, per location, that your AWS account can use. Learn more at Amazon EC2 Instance Types. The information returned includes the maximum number of instances allowed and your account's current usage across all fleets. This information can affect your ability to scale your GameLift fleets. You can request a limit increase for your account by using the Service limits page in the GameLift console. Instance limits differ based on whether the instances are deployed in a fleet's home Region or in a remote location. For remote locations, limits also differ based on the combination of home Region and remote location. All requests must specify an AWS Region (either explicitly or as your default settings). To get the limit for a remote location, you must also specify the location. For example, the following requests all return different results:    Request specifies the Region ap-northeast-1 with no location. The result is limits and usage data on all instance types that are deployed in us-east-2, by all of the fleets that reside in ap-northeast-1.    Request specifies the Region us-east-1 with location ca-central-1. The result is limits and usage data on all instance types that are deployed in ca-central-1, by all of the fleets that reside in us-east-2. These limits do not affect fleets in any other Regions that deploy instances to ca-central-1.   Request specifies the Region eu-west-1 with location ca-central-1. The result is limits and usage data on all instance types that are deployed in ca-central-1, by all of the fleets that reside in eu-west-1.   This operation can be used in the following ways:   To get limit and usage data for all instance types that are deployed in an AWS Region by fleets that reside in the same Region: Specify the Region only. Optionally, specify a single instance type to retrieve information for.   To get limit and usage data for all instance types that are deployed to a remote location by fleets that reside in different AWS Region: Provide both the AWS Region and the remote location. Optionally, specify a single instance type to retrieve information for.   If successful, an EC2InstanceLimits object is returned with limits and usage data for each requested instance type.  Learn more   Setting up GameLift fleets   Related actions   CreateFleet | UpdateFleetCapacity | PutScalingPolicy | DescribeEC2InstanceLimits | DescribeFleetAttributes | DescribeFleetLocationAttributes | UpdateFleetAttributes | StopFleetActions | DeleteFleet | All APIs by task

    Args:
        ec2_instance_type(str, optional): Name of an EC2 instance type that is supported in GameLift. A fleet instance type determines the computing resources of each instance in the fleet, including CPU, memory, storage, and networking capacity. Do not specify a value for this parameter to retrieve limits for all instance types. Defaults to None.
        location(str, optional): The name of a remote location to request instance limits for, in the form of an AWS Region code such as us-west-2. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.ec2_instance_limit.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.ec2_instance_limit.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_ec2_instance_limits",
        op_kwargs={"EC2InstanceType": ec2_instance_type, "Location": location},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    deployment_id: str = None,
    instance_id: str = None,
    command_ids: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the results of specified commands.  This call accepts only one resource-identifying parameter.   Required Permissions: To use this action, an IAM user must have a Show, Deploy, or Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information about user permissions, see Managing User Permissions.

    Args:
        deployment_id(str, optional): The deployment ID. If you include this parameter, DescribeCommands returns a description of the commands associated with the specified deployment. Defaults to None.
        instance_id(str, optional): The instance ID. If you include this parameter, DescribeCommands returns a description of the commands associated with the specified instance. Defaults to None.
        command_ids(List, optional): An array of command IDs. If you include this parameter, DescribeCommands returns a description of the specified commands. Otherwise, it returns a description of every command. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.command.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.command.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="describe_commands",
        op_kwargs={
            "DeploymentId": deployment_id,
            "InstanceId": instance_id,
            "CommandIds": command_ids,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, component_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     Gets a component policy.

    Args:
        component_arn(str): The Amazon Resource Name (ARN) of the component whose policy you want to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.component.policy.get(ctx, component_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.component.policy.get component_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="get_component_policy",
        op_kwargs={"componentArn": component_arn},
    )


async def put(hub, ctx, component_arn: str, policy: str) -> Dict:
    r"""
    **Autogenerated function**

     Applies a policy to a component. We recommend that you call the RAM API CreateResourceShare to share resources. If you call the Image Builder API PutComponentPolicy, you must also call the RAM API PromoteResourceShareCreatedFromPolicy in order for the resource to be visible to all principals with whom the resource is shared.

    Args:
        component_arn(str): The Amazon Resource Name (ARN) of the component that this policy should be applied to.
        policy(str): The policy to apply.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.component.policy.put(
                ctx, component_arn=value, policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.component.policy.put component_arn=value, policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="put_component_policy",
        op_kwargs={"componentArn": component_arn, "policy": policy},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub,
    ctx,
    database_name: str,
    table_name: str,
    partition_input_list: List,
    catalog_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates one or more partitions in a batch operation.

    Args:
        catalog_id(str, optional): The ID of the catalog in which the partition is to be created. Currently, this should be the Amazon Web Services account ID. Defaults to None.
        database_name(str): The name of the metadata database in which the partition is to be created.
        table_name(str): The name of the metadata table in which the partition is to be created.
        partition_input_list(List): A list of PartitionInput structures that define the partitions to be created.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.create_partition.batch(
                ctx, database_name=value, table_name=value, partition_input_list=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.create_partition.batch database_name=value, table_name=value, partition_input_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="batch_create_partition",
        op_kwargs={
            "CatalogId": catalog_id,
            "DatabaseName": database_name,
            "TableName": table_name,
            "PartitionInputList": partition_input_list,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    ec2_image_id: str,
    name: str,
    studio_id: str,
    client_token: str = None,
    description: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a streaming image resource in a studio.

    Args:
        client_token(str, optional): To make an idempotent API request using one of these actions, specify a client token in the request. You should not reuse the same client token for other API requests. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails with a ValidationException error. Defaults to None.
        description(str, optional): A human-readable description of the streaming image. Defaults to None.
        ec2_image_id(str): The ID of an EC2 machine image with which to create this streaming image.
        name(str): A friendly name for a streaming image resource.
        studio_id(str): The studio ID.
        tags(Dict, optional): A collection of labels, in the form of key:value pairs, that apply to this resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.streaming.image.create(
                ctx, ec2_image_id=value, name=value, studio_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.streaming.image.create ec2_image_id=value, name=value, studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="create_streaming_image",
        op_kwargs={
            "clientToken": client_token,
            "description": description,
            "ec2ImageId": ec2_image_id,
            "name": name,
            "studioId": studio_id,
            "tags": tags,
        },
    )


async def delete(
    hub, ctx, streaming_image_id: str, studio_id: str, client_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Delete streaming image.

    Args:
        client_token(str, optional): To make an idempotent API request using one of these actions, specify a client token in the request. You should not reuse the same client token for other API requests. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails with a ValidationException error. Defaults to None.
        streaming_image_id(str): The streaming image ID.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.streaming.image.delete(
                ctx, streaming_image_id=value, studio_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.streaming.image.delete streaming_image_id=value, studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="delete_streaming_image",
        op_kwargs={
            "clientToken": client_token,
            "streamingImageId": streaming_image_id,
            "studioId": studio_id,
        },
    )


async def get(hub, ctx, streaming_image_id: str, studio_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Get streaming image.

    Args:
        streaming_image_id(str): The streaming image ID.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.streaming.image.get(
                ctx, streaming_image_id=value, studio_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.streaming.image.get streaming_image_id=value, studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="get_streaming_image",
        op_kwargs={"streamingImageId": streaming_image_id, "studioId": studio_id},
    )


async def list_all(
    hub, ctx, studio_id: str, next_token: str = None, owner: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    List the streaming image resources available to this studio. This list will contain both images provided by AWS, as well as streaming images that you have created in your studio.

    Args:
        next_token(str, optional): The token for the next set of results, or null if there are no more results. Defaults to None.
        owner(str, optional): The owner. Defaults to None.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.streaming.image.list_all(ctx, studio_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.streaming.image.list_all studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="list_streaming_images",
        op_kwargs={"nextToken": next_token, "owner": owner, "studioId": studio_id},
    )


async def update(
    hub,
    ctx,
    streaming_image_id: str,
    studio_id: str,
    client_token: str = None,
    description: str = None,
    name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Update streaming image.

    Args:
        client_token(str, optional): To make an idempotent API request using one of these actions, specify a client token in the request. You should not reuse the same client token for other API requests. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails with a ValidationException error. Defaults to None.
        description(str, optional): The description. Defaults to None.
        name(str, optional): The name for the streaming image. Defaults to None.
        streaming_image_id(str): The streaming image ID.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.streaming.image.update(
                ctx, streaming_image_id=value, studio_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.streaming.image.update streaming_image_id=value, studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="update_streaming_image",
        op_kwargs={
            "clientToken": client_token,
            "description": description,
            "name": name,
            "streamingImageId": streaming_image_id,
            "studioId": studio_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    backup_id: str,
    subnet_ids: List,
    client_request_token: str = None,
    security_group_ids: List = None,
    tags: List = None,
    windows_configuration: Dict = None,
    lustre_configuration: Dict = None,
    storage_type: str = None,
    kms_key_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new Amazon FSx file system from an existing Amazon FSx backup. If a file system with the specified client request token exists and the parameters match, this operation returns the description of the file system. If a client request token specified by the file system exists and the parameters don't match, this call returns IncompatibleParameterError. If a file system with the specified client request token doesn't exist, this operation does the following:   Creates a new Amazon FSx file system from backup with an assigned ID, and an initial lifecycle state of CREATING.   Returns the description of the file system.   Parameters like Active Directory, default share name, automatic backup, and backup settings default to the parameters of the file system that was backed up, unless overridden. You can explicitly supply other settings. By using the idempotent operation, you can retry a CreateFileSystemFromBackup call without the risk of creating an extra file system. This approach can be useful when an initial call fails in a way that makes it unclear whether a file system was created. Examples are if a transport level timeout occurred, or your connection was reset. If you use the same client request token and the initial call created a file system, the client receives success as long as the parameters are the same.  The CreateFileSystemFromBackup call returns while the file system's lifecycle state is still CREATING. You can check the file-system creation status by calling the DescribeFileSystems operation, which returns the file system state along with other information.

    Args:
        backup_id(str): The ID of the source backup. Specifies the backup you are copying.
        client_request_token(str, optional): A string of up to 64 ASCII characters that Amazon FSx uses to ensure idempotent creation. This string is automatically filled on your behalf when you use the AWS Command Line Interface (AWS CLI) or an AWS SDK. Defaults to None.
        subnet_ids(List): Specifies the IDs of the subnets that the file system will be accessible from. For Windows MULTI_AZ_1 file system deployment types, provide exactly two subnet IDs, one for the preferred file server and one for the standby file server. You specify one of these subnets as the preferred subnet using the WindowsConfiguration > PreferredSubnetID property. For Windows SINGLE_AZ_1 and SINGLE_AZ_2 deployment types and Lustre file systems, provide exactly one subnet ID. The file server is launched in that subnet's Availability Zone.
        security_group_ids(List, optional): A list of IDs for the security groups that apply to the specified network interfaces created for file system access. These security groups apply to all network interfaces. This value isn't returned in later DescribeFileSystem requests. Defaults to None.
        tags(List, optional): The tags to be applied to the file system at file system creation. The key value of the Name tag appears in the console as the file system name. Defaults to None.
        windows_configuration(Dict, optional): The configuration for this Microsoft Windows file system. Defaults to None.
        lustre_configuration(Dict, optional): The Lustre configuration for the file system being created. . Defaults to None.
        storage_type(str, optional): Sets the storage type for the Windows file system you're creating from a backup. Valid values are SSD and HDD.   Set to SSD to use solid state drive storage. Supported on all Windows deployment types.   Set to HDD to use hard disk drive storage. Supported on SINGLE_AZ_2 and MULTI_AZ_1 Windows file system deployment types.     Default value is SSD.   HDD and SSD storage types have different minimum storage capacity requirements. A restored file system's storage capacity is tied to the file system that was backed up. You can create a file system that uses HDD storage from a backup of a file system that used SSD storage only if the original SSD file system had a storage capacity of at least 2000 GiB.  . Defaults to None.
        kms_key_id(str, optional): The ID of the AWS Key Management Service (AWS KMS) key used to encrypt the file system's data for Amazon FSx for Windows File Server file systems and Amazon FSx for Lustre PERSISTENT_1 file systems at rest. In either case, if not specified, the Amazon FSx managed key is used. The Amazon FSx for Lustre SCRATCH_1 and SCRATCH_2 file systems are always encrypted at rest using Amazon FSx managed keys. For more information, see Encrypt in the AWS Key Management Service API Reference. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fsx.file_system.from_backup.create(
                ctx, backup_id=value, subnet_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fsx.file_system.from_backup.create backup_id=value, subnet_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fsx",
        operation="create_file_system_from_backup",
        op_kwargs={
            "BackupId": backup_id,
            "ClientRequestToken": client_request_token,
            "SubnetIds": subnet_ids,
            "SecurityGroupIds": security_group_ids,
            "Tags": tags,
            "WindowsConfiguration": windows_configuration,
            "LustreConfiguration": lustre_configuration,
            "StorageType": storage_type,
            "KmsKeyId": kms_key_id,
        },
    )
